@@ -6,7 +6,7 @@ use Carp;
 use POE::Component::IRC::Plugin qw( :ALL );
 use POE::Component::IRC::Common qw( u_irc );
 
-my $VERSION = '1.0';
+my $VERSION = '1.1';
 
 sub new {
     my ($package, %self) = @_;
@@ -16,7 +16,9 @@ sub new {
 
 sub PCI_register {
     my ($self, $irc) = @_;
-    $self->{Nickname} = $irc->nick_name() unless $self->{Nickname};
+    if (!defined $self->{Nickname}) {
+        defined $irc->nick_name() ? $self->{Nickname} = $irc->nick_name() : $self->{Nickname} = $irc->{nick};
+    }
     $self->{Nickname} = u_irc $self->{Nickname};
     $irc->plugin_register($self, 'SERVER', qw(001 nick));
     return 1;
@@ -28,7 +30,7 @@ sub PCI_unregister {
 
 sub S_001 {
     my ($self, $irc) = splice @_, 0, 2;
-    if (u_irc $irc->nick_name() eq $self->{Nickname}) {
+    if (u_irc($irc->nick_name()) eq $self->{Nickname}) {
         $irc->yield(privmsg => nickserv => 'IDENTIFY ' . $self->{Password});
     }
     return PCI_EAT_NONE;
@@ -37,7 +39,7 @@ sub S_001 {
 sub S_nick {
     my ($self, $irc) = splice @_, 0, 2;
     my $new_nick = u_irc ${ $_[1] };
-    if ($new_nick eq u_irc $irc->nick_name() && $new_nick eq $self->{Nickname}) {
+    if ($new_nick eq u_irc($irc->nick_name()) && $new_nick eq $self->{Nickname}) {
         $irc->yield(privmsg => nickserv => 'IDENTIFY ' . $self->{Password});
     }
     return PCI_EAT_NONE;
@@ -70,9 +72,10 @@ the supplied password.
 
 Arguments:
 
- 'Nickname', the nickname that is associated with the password. Defaults to the nick returned
- by $irc->nick_name() at the time of plugin registration.
- 'Password', the NickServ password.
+'Nickname', the nickname that is associated with the password. Defaults to the nick returned
+by $irc->nick_name() at the time of plugin registration.
+
+'Password', the NickServ password.
 
 Returns a plugin object suitable for feeding to L<POE::Component::IRC|POE::Component::IRC>'s
 plugin_add() method.
