@@ -11,17 +11,18 @@ package POE::Component::IRC::State;
 
 use strict;
 use warnings;
+use POE;
 use POE::Component::IRC::Common qw(:ALL);
 use POE::Component::IRC::Plugin qw(:ALL);
 use base qw(POE::Component::IRC);
 use vars qw($VERSION);
-use Data::Dumper;
 
-$VERSION = '2.44';
+$VERSION = '2.46';
 
 # Event handlers for tracking the STATE. $self->{STATE} is used as our namespace.
 # u_irc() is used to create unique keys.
 
+# RPL_WELCOME
 # Make sure we have a clean STATE when we first join the network and if we inadvertently get disconnected
 sub S_001 {
   my $self = shift;
@@ -76,6 +77,8 @@ sub S_join {
         $self->yield ( 'who' => $channel );
         $self->yield ( 'mode' => $channel );
         $self->yield ( 'mode' => $channel => 'b');
+        $poe_kernel->state( '_away_sync' => $self );
+        $poe_kernel->delay_add( '_away_sync' => 60 => $channel );
 
   } else {
         $self->yield ( 'who' => $nick );
@@ -220,6 +223,7 @@ sub S_chan_mode {
   return PCI_EAT_NONE;
 }
 
+# RPL_UMODEIS
 sub S_221 {
   my ($self,$irc) = splice @_, 0, 2;
   my $mode = ${ $_[1] };
@@ -228,16 +232,22 @@ sub S_221 {
   return PCI_EAT_NONE;
 }
 
+# RPL_UNAWAY
 sub S_305 {
-	my ($self,$irc) = splice @_, 0, 2;
-	delete $self->{STATE}->{away};
-	return PCI_EAT_NONE;
+  my ($self,$irc) = splice @_, 0, 2;
+  my $nick = $irc->nick_name();
+  $self->yield( 'irc_user_away' => $nick => [ $self->nick_channels( $nick ) ] ) if $self->{STATE}->{away};
+  $self->{STATE}->{away} = 0;
+  return PCI_EAT_NONE;
 }
 
+# RPL_NOWAWAY
 sub S_306 {
-	my ($self,$irc) = splice @_, 0, 2;
-	$self->{STATE}->{away} = 1;
-	return PCI_EAT_NONE;
+  my ($self,$irc) = splice @_, 0, 2;
+  my $nick = $irc->nick_name();
+    $self->yield( 'irc_user_back' => $nick => [ $self->nick_channels( $nick ) ] ) unless $self->{STATE}->{away};
+  $self->{STATE}->{away} = 1;
+  return PCI_EAT_NONE;
 }
 
 # Channel MODE
@@ -376,7 +386,7 @@ sub S_352 {
   $self->{STATE}->{Nicks}->{ $unick }->{Host} = $host;
   $self->{STATE}->{Nicks}->{ $unick }->{Real} = $real;
   $self->{STATE}->{Nicks}->{ $unick }->{Server} = $server;
-  if ( $channel ne '*' ) {
+  if ( exists $self->{STATE}->{Chans}->{ $uchan } ) {
     my $whatever = '';
     my $existing = $self->{STATE}->{Nicks}->{ $unick }->{CHANS}->{ $uchan } || '';    
     my $prefix = $irc->isupport('PREFIX') || { 'o', '@', 'v', '+' };
@@ -387,6 +397,14 @@ sub S_352 {
     $self->{STATE}->{Nicks}->{ $unick }->{CHANS}->{ $uchan } = $existing;
     $self->{STATE}->{Chans}->{ $uchan }->{Nicks}->{ $unick } = $existing;
     $self->{STATE}->{Chans}->{ $uchan }->{Name} = $channel;
+    if ($self->{STATE}->{Chans}->{ $uchan }->{AWAY_SYNCH}) {
+      if ( $status =~ /G/ && !$self->{STATE}->{Nicks}->{ $unick }->{Away} ) {
+        $self->yield( 'irc_user_away' => $nick => [ $self->nick_channels( $nick ) ] ) unless $unick eq uirc $irc->nick_name();
+      }
+      elsif ($status =~ /H/ && $self->{STATE}->{Nicks}->{ $unick }->{Away} ) {
+        $self->yield( 'irc_user_back' => $nick => [ $self->nick_channels( $nick ) ] ) unless $unick eq uirc $irc->nick_name();;
+      }
+    }
   }
   if ( $status =~ /\*/ ) {
     $self->{STATE}->{Nicks}->{ $unick }->{IRCop} = 1;
@@ -408,17 +426,21 @@ sub S_315 {
   my $channel = ${ $_[2] }->[0];
   my $uchan = u_irc $channel, $mapping;
 
-  # If it begins with #, &, + or ! its a channel apparently. RFC2812.
-  if ( $channel =~ /^[\x23\x2B\x21\x26]/ ) {
+  if ( exists $self->{STATE}->{Chans}->{ $uchan } ) {
     if ( $self->_channel_sync($channel, 'WHO') ) {
-	my $rec = delete $self->{CHANNEL_SYNCH}->{ $uchan };
-	$self->_send_event( 'irc_chan_sync', $channel, time() - $rec->{_time} );
+      my $rec = delete $self->{CHANNEL_SYNCH}->{ $uchan };
+      $self->_send_event( 'irc_chan_sync', $channel, time() - $rec->{_time} );
     }
-  # Otherwise we assume its a nickname
-  } else {
-	my $chan = shift @{ $self->{NICK_SYNCH}->{ $uchan } };
-	delete $self->{NICK_SYNCH}->{ $uchan } unless scalar @{ $self->{NICK_SYNCH}->{ $uchan } };
-	$self->_send_event( 'irc_nick_sync', $channel, $chan );
+    elsif ( $self->{STATE}->{Chans}->{ $uchan }->{AWAY_SYNCH} ) {
+      $self->{STATE}->{Chans}->{ $uchan }->{AWAY_SYNCH} = 0;
+      $self->_send_event( 'irc_away_sync_end', $channel );
+      $poe_kernel->delay_add( '_away_sync' => 60 => $channel );
+    }
+  }
+  else {
+    my $chan = shift @{ $self->{NICK_SYNCH}->{ $uchan } };
+    delete $self->{NICK_SYNCH}->{ $uchan } unless scalar @{ $self->{NICK_SYNCH}->{ $uchan } };
+    $self->_send_event( 'irc_nick_sync', $channel, $chan );
   }
   return PCI_EAT_NONE;
 }
@@ -585,6 +607,13 @@ sub is_user_mode_set {
   return 0;
 }
 
+sub _away_sync {
+  my ($self, $channel) = @_[OBJECT, ARG0];
+  my $uchan = u_irc $channel;
+  $self->{STATE}->{Chans}->{ $uchan }->{AWAY_SYNCH} = 1;
+  $self->_send_event( 'irc_away_sync_start', $channel );
+  $self->yield( 'who' => $channel );
+}
 
 sub _channel_sync {
   my $self = shift;
@@ -1074,8 +1103,7 @@ to not be on that channel an empty list will be returned.
 =item is_away
 
 Expects a nick as parameter. Returns 1 if the specified nick is away or 0 otherwise. If the nick does
-not exist in the state then a 0 will be returned. This is only guaranteed to be accurate for the Component's
-nick.
+not exist in the state then a 0 will be returned.
 
 =item is_operator
 
@@ -1184,6 +1212,14 @@ As well as all the usual L<POE::Component::IRC> 'irc_*' events, there are the fo
 
 =over
 
+=item irc_away_sync_start
+
+Sent whenever the component starts to synchronise the away statuses of channel members. It does this every 60 seconds. ARG0 is the channel name.
+
+=item irc_away_sync_end
+
+Sent whenever the component has completed synchronising the away statuses of channel members. It does this every 60 seconds. ARG0 is the channel name.
+
 =item irc_chan_sync
 
 Sent whenever the component has completed synchronising a channel that it has joined. ARG0 is the channel name and ARG1 is the time in seconds that the channel took to synchronise.
@@ -1210,6 +1246,14 @@ argument if it has one (ie. the banmask if it's +b or -b). However, this event i
 
 This is almost identical to irc_mode, except it is sent for each individual umode that is being set.
 
+=item irc_user_away
+
+Sent when an IRC user sets his/her status to away. ARG0 is the nickname, ARG1 is an arrayref of channel names that are common to the nickname and the component.
+
+=item irc_user_back
+
+Sent when an IRC user unsets his/her away status. ARG0 is the nickname, ARG1 is an arrayref of channel names that are common to the nickname and the component.
+
 =back
 
 The following two 'irc_*' events are the same as their L<POE::Component::IRC> counterparts,
@@ -1234,8 +1278,10 @@ Additional parameter ARG4 contains the full nick!user@host of the kicked individ
 =head1 CAVEATS
 
 The component gathers information by registering for 'irc_quit', 'irc_nick', 'irc_join', 'irc_part', 'irc_mode', 'irc_kick' and
-various numeric replies. When the component is asked to join a channel, when it joins it will issue a 'WHO #channel' and a 'MODE #channel'. These will solicit between them the numerics, 'irc_352' and 'irc_324'.
-You may want to ignore these. When someone joins a channel the bot is on, it issues a 'WHO nick'.
+various numeric replies. When the component is asked to join a channel, when it joins it will issue 'WHO #channel', 'MODE #channel',
+and 'MODE #channel b'. These will solicit between them the numerics, 'irc_352', 'irc_324' and 'irc_329', respectively.
+'WHO #channel' will then be issued once every minute from then on. When someone joins a channel the bot is on, it issues a 'WHO nick'.
+You may want to ignore these. 
 
 Currently, whenever the component sees a topic or channel list change, it will use time() for the SetAt value and the full address of the user who set it for the SetBy value. When an ircd gives us it's record 
 of such changes, it will use it's own time (obviously) and may only give us the nickname of the user, rather than their full address. Thus, if our time() and the ircd's time do not match, or the ircd uses the
